from setuptools import setup

setup(name='GaussBinomDist',
      version='0.1',
      description='Gaussian and Binomial distributions',
      author = 'Generic',
      packages=['GaussBinomDist'],
      zip_safe=False)
